# Inngest SDK Package

## Package Overview

Refer to `CONTRIBUTING.md`.

**Key Features:**

- Event-driven
- Steps are invididually-retryable units of work
- Framework-agnostic design (e.g. Flask). Framework-specific code is limited to individual files (e.g. `flask.py`)
- Support both async and sync code
- Built-in middleware system
- Excellent static type safety

## Development Environment

Refer to `CONTRIBUTING.md`.

**Build & Release:**

Do not consider building and releasing. This is automatically done in CI.

## Architecture Guidelines

Refer to `CONTRIBUTING.md`.

## Testing Patterns

Refer to `CONTRIBUTING.md`.

## Key Dependencies

**Dependencies:**

Minimize the number of dependencies.
